/***********************************************************************************************************************
 *
 * blueBill Core - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it
 * SCM: https://kenai.com/hg/bluebill~core-src
 *
 **********************************************************************************************************************/
package it.tidalwave.semantic.vocabulary;

import it.tidalwave.util.Id;
import it.tidalwave.util.Key;
import it.tidalwave.semantic.EntityWithProperties;
import it.tidalwave.semantic.Type;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public final class DublinCoreVocabulary
  {
    private DublinCoreVocabulary()
      {
      }

    public static final String NS_DC                    = "http://purl.org/dc/elements/1.1/";
    public static final String NS_DC_TERMS              = "http://purl.org/dc/terms/";
    public static final String NS_DCMI_TYPE             = "http://purl.org/dc/dcmitype/";

    public static final Id ID_DC_ABSTRACT               = new Id(NS_DC + "abstract");
    public static final Id ID_DC_CREATOR                = new Id(NS_DC + "creator");
    public static final Id ID_DC_DATE                   = new Id(NS_DC + "date");
    public static final Id ID_DC_PUBLISHER              = new Id(NS_DC + "publisher");
    public static final Id ID_DC_TITLE                  = new Id(NS_DC + "title");
    public static final Id ID_DC_RIGHTS                 = new Id(NS_DC + "rights");
    public static final Id ID_DC_TYPE                   = new Id(NS_DC + "type");
    public static final Id ID_DC_FORMAT                 = new Id(NS_DC + "format");
    public static final Id ID_DC_IDENTIFIER             = new Id(NS_DC + "identifier");
    public static final Id ID_DC_DESCRIPTION            = new Id(NS_DC + "description");
    
    public static final Id ID_STILL_IMAGE               = new Id(NS_DCMI_TYPE + "StillImage"); 
    public static final Id ID_MOVING_IMAGE              = new Id(NS_DCMI_TYPE + "MovingImage"); 
    public static final Id ID_SOUND                     = new Id(NS_DCMI_TYPE + "Sound"); 
    
    public static final Type TYPE_STILL_IMAGE           = new Type(ID_STILL_IMAGE);
    public static final Type TYPE_MOVING_IMAGE          = new Type(ID_MOVING_IMAGE);
    public static final Type TYPE_SOUND                 = new Type(ID_SOUND);
    
    public static final Key<String> DC_ABSTRACT         = new Key<String>(ID_DC_ABSTRACT);
    public static final Key<EntityWithProperties<?>> DC_CREATOR   = new Key<EntityWithProperties<?>>(ID_DC_CREATOR);
    public static final Key<EntityWithProperties<?>> DC_PUBLISHER = new Key<EntityWithProperties<?>>(ID_DC_PUBLISHER);
    public static final Key<String> DC_TITLE            = new Key<String>(ID_DC_TITLE);
    public static final Key<String> DC_RIGHTS           = new Key<String>(ID_DC_RIGHTS);
    public static final Key<String> DC_TYPE             = new Key<String>(ID_DC_TYPE);
    public static final Key<String> DC_FORMAT           = new Key<String>(ID_DC_FORMAT);
    public static final Key<Id> DC_IDENTIFIER           = new Key<Id>(ID_DC_IDENTIFIER);
    public static final Key<String> DC_DESCRIPTION      = new Key<String>(ID_DC_DESCRIPTION);
  }
